"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var js_yaml_1 = __importDefault(require("js-yaml"));
var http_json_1 = __importDefault(require("./bindingTemplates/http.json"));
var FuncPluginUtils = /** @class */ (function () {
    function FuncPluginUtils() {
    }
    FuncPluginUtils.getServerlessYml = function (sls) {
        return sls.utils.readFileSync("serverless.yml");
    };
    FuncPluginUtils.getFunctionsYml = function (sls, serverlessYml) {
        serverlessYml = serverlessYml || FuncPluginUtils.getServerlessYml(sls);
        return serverlessYml["functions"];
    };
    FuncPluginUtils.updateFunctionsYml = function (sls, functionYml, serverlessYml) {
        serverlessYml = serverlessYml || FuncPluginUtils.getServerlessYml(sls);
        serverlessYml["functions"] = functionYml;
        sls.utils.writeFileSync("serverless.yml", js_yaml_1.default.dump(serverlessYml));
    };
    FuncPluginUtils.getFunctionHandler = function (name) {
        return "\"use strict\";\n\nmodule.exports.handler = async function (context, req) {\n  context.log(\"JavaScript HTTP trigger function processed a request.\");\n\n  if (req.query.name || (req.body && req.body.name)) {\n    context.res = {\n      // status: 200, /* Defaults to 200 */\n      body: \"" + name + " \" + (req.query.name || req.body.name)\n    };\n  }\n  else {\n    context.res = {\n      status: 400,\n      body: \"Please pass a name on the query string or in the request body\"\n    };\n  }\n};";
    };
    FuncPluginUtils.getFunctionJsonString = function (name, options) {
        // TODO: This is where we would just generate function JSON from SLS object
        // using getFunctionSlsObject(name, options). Currently defaulting to http in and out
        return JSON.stringify(http_json_1.default, null, 2);
    };
    FuncPluginUtils.getFunctionSlsObject = function (name, options) {
        return FuncPluginUtils.defaultFunctionSlsObject(name);
    };
    FuncPluginUtils.defaultFunctionSlsObject = function (name) {
        return {
            handler: "src/handlers/" + name + ".handler",
            events: FuncPluginUtils.httpEvents()
        };
    };
    FuncPluginUtils.httpEvents = function () {
        return [
            {
                http: true,
                "x-azure-settings": {
                    authLevel: "anonymous"
                }
            },
            {
                http: true,
                "x-azure-settings": {
                    direction: "out",
                    name: "res"
                }
            },
        ];
    };
    return FuncPluginUtils;
}());
exports.FuncPluginUtils = FuncPluginUtils;
