/// <reference types="jest" />
import { ApiContract, ApiManagementServiceResource } from "@azure/arm-apimanagement/esm/models";
import { Site, FunctionEnvelope } from "@azure/arm-appservice/esm/models";
import { HttpOperationResponse } from "@azure/ms-rest-js";
import { AuthResponse } from "@azure/ms-rest-nodeauth";
import { TokenClientCredentials } from "@azure/ms-rest-nodeauth/dist/lib/credentials/tokenClientCredentials";
import { AxiosRequestConfig, AxiosResponse } from "axios";
import Serverless from "serverless";
import Service from "serverless/classes/Service";
import { ServerlessAzureConfig } from "../models/serverless";
import { AzureServiceProvider, ServicePrincipalEnvVariables } from "../models/azureProvider";
import { ApiCorsPolicy } from "../models/apiManagement";
export declare class MockFactory {
    static createTestServerless(config?: any): Serverless;
    static createTestServerlessOptions(): Serverless.Options;
    static createTestArmSdkResponse<R>(model: any, statusCode: number): Promise<R>;
    static createTestAuthResponse(): AuthResponse;
    static createTestAzureCredentials(): TokenClientCredentials;
    static createTestAxiosResponse<T>(config: AxiosRequestConfig, responseJson: T, statusCode?: number): Promise<AxiosResponse>;
    static createTestAzureClientResponse<T>(responseJson: T, statusCode?: number): Promise<HttpOperationResponse>;
    static createTestServerlessYml(asYaml?: boolean, functionMetadata?: any): ServerlessAzureConfig;
    static createTestFunctionsMetadata(functionCount?: number): {};
    static createTestFunctionApimConfig(name: string): {
        apim: {
            operations: {
                method: string;
                urlTemplate: string;
                displayName: string;
            }[];
        };
    };
    static createTestFunctionMetadata(name: string): {
        handler: string;
        events: ({
            http: boolean;
            "x-azure-settings": {
                authLevel: string;
                direction?: undefined;
                name?: undefined;
            };
        } | {
            http: boolean;
            "x-azure-settings": {
                direction: string;
                name: string;
                authLevel?: undefined;
            };
        })[];
    };
    static createTestService(functions?: any): Service;
    static createTestFunctionsResponse(functions?: any): any[];
    static createTestAzureServiceProvider(): AzureServiceProvider;
    static createTestServicePrincipalEnvVariables(): ServicePrincipalEnvVariables;
    static createTestVariables(): {
        azureCredentials: {
            tokenCache: {
                _entries: {
                    accessToken: string;
                }[];
            };
        };
        subscriptionId: string;
    };
    static createTestSite(name?: string): Site;
    static createTestFunctionEnvelope(name?: string): FunctionEnvelope;
    static createTestBindings(bindingCount?: number): any[];
    static createTestBinding(): {
        type: string;
        authLevel: string;
        direction: string;
        methods: string[];
    };
    static createTestHttpBinding(): {
        type: string;
        authLevel: string;
        direction: string;
        methods: string[];
    };
    static createTestSlsFunctionConfig(): {
        hello: {
            apim: {
                operations: {
                    method: string;
                    urlTemplate: string;
                    displayName: string;
                }[];
            };
            handler: string;
            events: ({
                http: boolean;
                "x-azure-settings": {
                    authLevel: string;
                    direction?: undefined;
                    name?: undefined;
                };
            } | {
                http: boolean;
                "x-azure-settings": {
                    direction: string;
                    name: string;
                    authLevel?: undefined;
                };
            })[];
        };
        goodbye: {
            apim: {
                operations: {
                    method: string;
                    urlTemplate: string;
                    displayName: string;
                }[];
            };
            handler: string;
            events: ({
                http: boolean;
                "x-azure-settings": {
                    authLevel: string;
                    direction?: undefined;
                    name?: undefined;
                };
            } | {
                http: boolean;
                "x-azure-settings": {
                    direction: string;
                    name: string;
                    authLevel?: undefined;
                };
            })[];
        };
    };
    static createTestApimService(): ApiManagementServiceResource;
    static createTestApimApi(): ApiContract;
    private static createTestUtils;
    /**
     * Create a mock "request" module factory used to mock request objects that support piping
     * @param response The expected HTTP response
     */
    static createTestMockRequestFactory(response?: any): jest.Mock<{
        on: jest.Mock<any, any>;
        once: jest.Mock<any, any>;
        emit: jest.Mock<any, any>;
        write: jest.Mock<any, any>;
        end: jest.Mock<any, any>;
    }, [any, any]>;
    static createTestMockApiCorsPolicy(): ApiCorsPolicy;
    private static createTestCli;
    private static createTestPluginManager;
}
